from setuptools import setup

setup(name='enrichwrap',
      version='0.0.2',
      description='Sample enrichment wrapper',
      #url='http://github.com/storborg/funniest',
      author='Sue Hannum',
      author_email='Sue.Hannum@sas.com',
      license='MIT',
      packages=['enrichwrap'],
      zip_safe=False)
